diff --git a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2015_06_15/models/_models.py b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2015_06_15/models/_models.py
index 05bf39c9a37d..7af1d3d0caf1 100644
--- a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2015_06_15/models/_models.py
+++ b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2015_06_15/models/_models.py
@@ -529,7 +529,8 @@ class ImageReference(Model):
about platform images, marketplace images, or virtual machine images. This
element is required when you want to use a platform image, marketplace
image, or virtual machine image, but is not used in other creation
- operations.
+ operations. NOTE: Image reference publisher and offer can only be set when
+ you create the scale set.
:param publisher: The image publisher.
:type publisher: str
@@ -1058,7 +1059,9 @@ def __init__(self, **kwargs):
class Sku(Model):
- """Describes a virtual machine scale set sku.
+ """Describes a virtual machine scale set sku. NOTE: If the new VM SKU is not
+ supported on the hardware the scale set is currently on, you need to
+ deallocate the VMs in the scale set before you modify the SKU name.
:param name: The sku name.
:type name: str
diff --git a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2015_06_15/models/_models_py3.py b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2015_06_15/models/_models_py3.py
index 0c38d43b99e2..df03207420a3 100644
--- a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2015_06_15/models/_models_py3.py
+++ b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2015_06_15/models/_models_py3.py
@@ -529,7 +529,8 @@ class ImageReference(Model):
about platform images, marketplace images, or virtual machine images. This
element is required when you want to use a platform image, marketplace
image, or virtual machine image, but is not used in other creation
- operations.
+ operations. NOTE: Image reference publisher and offer can only be set when
+ you create the scale set.
:param publisher: The image publisher.
:type publisher: str
@@ -1058,7 +1059,9 @@ def __init__(self, *, publisher: str, name: str, product: str, **kwargs) -> None
class Sku(Model):
- """Describes a virtual machine scale set sku.
+ """Describes a virtual machine scale set sku. NOTE: If the new VM SKU is not
+ supported on the hardware the scale set is currently on, you need to
+ deallocate the VMs in the scale set before you modify the SKU name.
:param name: The sku name.
:type name: str
diff --git a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2016_03_30/models/_models.py b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2016_03_30/models/_models.py
index ac04c2ac931f..11c602c3d1ef 100644
--- a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2016_03_30/models/_models.py
+++ b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2016_03_30/models/_models.py
@@ -526,7 +526,8 @@ class ImageReference(Model):
about platform images, marketplace images, or virtual machine images. This
element is required when you want to use a platform image, marketplace
image, or virtual machine image, but is not used in other creation
- operations.
+ operations. NOTE: Image reference publisher and offer can only be set when
+ you create the scale set.
:param publisher: The image publisher.
:type publisher: str
@@ -1055,7 +1056,9 @@ def __init__(self, **kwargs):
class Sku(Model):
- """Describes a virtual machine scale set sku.
+ """Describes a virtual machine scale set sku. NOTE: If the new VM SKU is not
+ supported on the hardware the scale set is currently on, you need to
+ deallocate the VMs in the scale set before you modify the SKU name.
:param name: The sku name.
:type name: str
diff --git a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2016_03_30/models/_models_py3.py b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2016_03_30/models/_models_py3.py
index 7e5ebcc548b3..4d12de304561 100644
--- a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2016_03_30/models/_models_py3.py
+++ b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2016_03_30/models/_models_py3.py
@@ -526,7 +526,8 @@ class ImageReference(Model):
about platform images, marketplace images, or virtual machine images. This
element is required when you want to use a platform image, marketplace
image, or virtual machine image, but is not used in other creation
- operations.
+ operations. NOTE: Image reference publisher and offer can only be set when
+ you create the scale set.
:param publisher: The image publisher.
:type publisher: str
@@ -1055,7 +1056,9 @@ def __init__(self, *, publisher: str, name: str, product: str, **kwargs) -> None
class Sku(Model):
- """Describes a virtual machine scale set sku.
+ """Describes a virtual machine scale set sku. NOTE: If the new VM SKU is not
+ supported on the hardware the scale set is currently on, you need to
+ deallocate the VMs in the scale set before you modify the SKU name.
:param name: The sku name.
:type name: str
diff --git a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2017_03_30/models/_models.py b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2017_03_30/models/_models.py
index 128fc870bf02..eccc4f2acc4c 100644
--- a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2017_03_30/models/_models.py
+++ b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2017_03_30/models/_models.py
@@ -1075,7 +1075,8 @@ class ImageReference(SubResource):
about platform images, marketplace images, or virtual machine images. This
element is required when you want to use a platform image, marketplace
image, or virtual machine image, but is not used in other creation
- operations.
+ operations. NOTE: Image reference publisher and offer can only be set when
+ you create the scale set.
:param id: Resource Id
:type id: str
@@ -2414,7 +2415,9 @@ class Sku(Model):
/>
Possible Values:
**Standard**
**Basic**
:type tier: str
:param capacity: Specifies the number of virtual machines in the scale
- set.
+ set. NOTE: If the new VM SKU is not supported on the hardware the scale
+ set is currently on, you need to deallocate the VMs in the scale set
+ before you modify the SKU name.
:type capacity: long
"""
@@ -3605,7 +3608,8 @@ class VirtualMachineScaleSet(Resource):
configured.
:type identity:
~azure.mgmt.compute.v2017_03_30.models.VirtualMachineScaleSetIdentity
- :param zones: The virtual machine scale set zones.
+ :param zones: The virtual machine scale set zones. NOTE: Availability
+ zones can only be set when you create the scale set.
:type zones: list[str]
"""
@@ -4410,7 +4414,9 @@ class VirtualMachineScaleSetUpdate(UpdateResource):
should be overprovisioned.
:type overprovision: bool
:param single_placement_group: When true this limits the scale set to a
- single placement group, of max size 100 virtual machines.
+ single placement group, of max size 100 virtual machines. NOTE: If
+ singlePlacementGroup is true, it may be modified to false. However, if
+ singlePlacementGroup is false, it may not be modified to true.
:type single_placement_group: bool
:param identity: The identity of the virtual machine scale set, if
configured.
diff --git a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2017_03_30/models/_models_py3.py b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2017_03_30/models/_models_py3.py
index 03a4d6a57e3e..8fb40784cede 100644
--- a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2017_03_30/models/_models_py3.py
+++ b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2017_03_30/models/_models_py3.py
@@ -1075,7 +1075,8 @@ class ImageReference(SubResource):
about platform images, marketplace images, or virtual machine images. This
element is required when you want to use a platform image, marketplace
image, or virtual machine image, but is not used in other creation
- operations.
+ operations. NOTE: Image reference publisher and offer can only be set when
+ you create the scale set.
:param id: Resource Id
:type id: str
@@ -2414,7 +2415,9 @@ class Sku(Model):
/>
Possible Values:
**Standard**
**Basic**
:type tier: str
:param capacity: Specifies the number of virtual machines in the scale
- set.
+ set. NOTE: If the new VM SKU is not supported on the hardware the scale
+ set is currently on, you need to deallocate the VMs in the scale set
+ before you modify the SKU name.
:type capacity: long
"""
@@ -3605,7 +3608,8 @@ class VirtualMachineScaleSet(Resource):
configured.
:type identity:
~azure.mgmt.compute.v2017_03_30.models.VirtualMachineScaleSetIdentity
- :param zones: The virtual machine scale set zones.
+ :param zones: The virtual machine scale set zones. NOTE: Availability
+ zones can only be set when you create the scale set.
:type zones: list[str]
"""
@@ -4410,7 +4414,9 @@ class VirtualMachineScaleSetUpdate(UpdateResource):
should be overprovisioned.
:type overprovision: bool
:param single_placement_group: When true this limits the scale set to a
- single placement group, of max size 100 virtual machines.
+ single placement group, of max size 100 virtual machines. NOTE: If
+ singlePlacementGroup is true, it may be modified to false. However, if
+ singlePlacementGroup is false, it may not be modified to true.
:type single_placement_group: bool
:param identity: The identity of the virtual machine scale set, if
configured.
diff --git a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2017_12_01/models/_models.py b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2017_12_01/models/_models.py
index fa444d53a365..472073760391 100644
--- a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2017_12_01/models/_models.py
+++ b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2017_12_01/models/_models.py
@@ -896,7 +896,8 @@ class ImageReference(SubResource):
about platform images, marketplace images, or virtual machine images. This
element is required when you want to use a platform image, marketplace
image, or virtual machine image, but is not used in other creation
- operations.
+ operations. NOTE: Image reference publisher and offer can only be set when
+ you create the scale set.
:param id: Resource Id
:type id: str
@@ -2217,7 +2218,9 @@ def __init__(self, **kwargs):
class Sku(Model):
- """Describes a virtual machine scale set sku.
+ """Describes a virtual machine scale set sku. NOTE: If the new VM SKU is not
+ supported on the hardware the scale set is currently on, you need to
+ deallocate the VMs in the scale set before you modify the SKU name.
:param name: The sku name.
:type name: str
@@ -3463,7 +3466,8 @@ class VirtualMachineScaleSet(Resource):
configured.
:type identity:
~azure.mgmt.compute.v2017_12_01.models.VirtualMachineScaleSetIdentity
- :param zones: The virtual machine scale set zones.
+ :param zones: The virtual machine scale set zones. NOTE: Availability
+ zones can only be set when you create the scale set.
:type zones: list[str]
"""
@@ -4297,7 +4301,9 @@ class VirtualMachineScaleSetUpdate(UpdateResource):
should be overprovisioned.
:type overprovision: bool
:param single_placement_group: When true this limits the scale set to a
- single placement group, of max size 100 virtual machines.
+ single placement group, of max size 100 virtual machines. NOTE: If
+ singlePlacementGroup is true, it may be modified to false. However, if
+ singlePlacementGroup is false, it may not be modified to true.
:type single_placement_group: bool
:param identity: The identity of the virtual machine scale set, if
configured.
diff --git a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2017_12_01/models/_models_py3.py b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2017_12_01/models/_models_py3.py
index 19ac1722d0f5..d49cd4814811 100644
--- a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2017_12_01/models/_models_py3.py
+++ b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2017_12_01/models/_models_py3.py
@@ -896,7 +896,8 @@ class ImageReference(SubResource):
about platform images, marketplace images, or virtual machine images. This
element is required when you want to use a platform image, marketplace
image, or virtual machine image, but is not used in other creation
- operations.
+ operations. NOTE: Image reference publisher and offer can only be set when
+ you create the scale set.
:param id: Resource Id
:type id: str
@@ -2217,7 +2218,9 @@ def __init__(self, *, output=None, **kwargs) -> None:
class Sku(Model):
- """Describes a virtual machine scale set sku.
+ """Describes a virtual machine scale set sku. NOTE: If the new VM SKU is not
+ supported on the hardware the scale set is currently on, you need to
+ deallocate the VMs in the scale set before you modify the SKU name.
:param name: The sku name.
:type name: str
@@ -3463,7 +3466,8 @@ class VirtualMachineScaleSet(Resource):
configured.
:type identity:
~azure.mgmt.compute.v2017_12_01.models.VirtualMachineScaleSetIdentity
- :param zones: The virtual machine scale set zones.
+ :param zones: The virtual machine scale set zones. NOTE: Availability
+ zones can only be set when you create the scale set.
:type zones: list[str]
"""
@@ -4297,7 +4301,9 @@ class VirtualMachineScaleSetUpdate(UpdateResource):
should be overprovisioned.
:type overprovision: bool
:param single_placement_group: When true this limits the scale set to a
- single placement group, of max size 100 virtual machines.
+ single placement group, of max size 100 virtual machines. NOTE: If
+ singlePlacementGroup is true, it may be modified to false. However, if
+ singlePlacementGroup is false, it may not be modified to true.
:type single_placement_group: bool
:param identity: The identity of the virtual machine scale set, if
configured.
diff --git a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2018_04_01/models/_models.py b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2018_04_01/models/_models.py
index 3708dd6937d2..b120808da5b8 100644
--- a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2018_04_01/models/_models.py
+++ b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2018_04_01/models/_models.py
@@ -1217,7 +1217,8 @@ class ImageReference(SubResource):
about platform images, marketplace images, or virtual machine images. This
element is required when you want to use a platform image, marketplace
image, or virtual machine image, but is not used in other creation
- operations.
+ operations. NOTE: Image reference publisher and offer can only be set when
+ you create the scale set.
:param id: Resource Id
:type id: str
@@ -2591,7 +2592,9 @@ def __init__(self, **kwargs):
class Sku(Model):
- """Describes a virtual machine scale set sku.
+ """Describes a virtual machine scale set sku. NOTE: If the new VM SKU is not
+ supported on the hardware the scale set is currently on, you need to
+ deallocate the VMs in the scale set before you modify the SKU name.
:param name: The sku name.
:type name: str
@@ -4039,7 +4042,8 @@ class VirtualMachineScaleSet(Resource):
configured.
:type identity:
~azure.mgmt.compute.v2018_04_01.models.VirtualMachineScaleSetIdentity
- :param zones: The virtual machine scale set zones.
+ :param zones: The virtual machine scale set zones. NOTE: Availability
+ zones can only be set when you create the scale set.
:type zones: list[str]
"""
@@ -4908,7 +4912,9 @@ class VirtualMachineScaleSetUpdate(UpdateResource):
should be overprovisioned.
:type overprovision: bool
:param single_placement_group: When true this limits the scale set to a
- single placement group, of max size 100 virtual machines.
+ single placement group, of max size 100 virtual machines. NOTE: If
+ singlePlacementGroup is true, it may be modified to false. However, if
+ singlePlacementGroup is false, it may not be modified to true.
:type single_placement_group: bool
:param proximity_placement_group: Specifies information about the
proximity placement group that the virtual machine scale set should be
diff --git a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2018_04_01/models/_models_py3.py b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2018_04_01/models/_models_py3.py
index d0c8f23f05b6..ff28778af1f4 100644
--- a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2018_04_01/models/_models_py3.py
+++ b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2018_04_01/models/_models_py3.py
@@ -1217,7 +1217,8 @@ class ImageReference(SubResource):
about platform images, marketplace images, or virtual machine images. This
element is required when you want to use a platform image, marketplace
image, or virtual machine image, but is not used in other creation
- operations.
+ operations. NOTE: Image reference publisher and offer can only be set when
+ you create the scale set.
:param id: Resource Id
:type id: str
@@ -2591,7 +2592,9 @@ def __init__(self, *, value=None, **kwargs) -> None:
class Sku(Model):
- """Describes a virtual machine scale set sku.
+ """Describes a virtual machine scale set sku. NOTE: If the new VM SKU is not
+ supported on the hardware the scale set is currently on, you need to
+ deallocate the VMs in the scale set before you modify the SKU name.
:param name: The sku name.
:type name: str
@@ -4039,7 +4042,8 @@ class VirtualMachineScaleSet(Resource):
configured.
:type identity:
~azure.mgmt.compute.v2018_04_01.models.VirtualMachineScaleSetIdentity
- :param zones: The virtual machine scale set zones.
+ :param zones: The virtual machine scale set zones. NOTE: Availability
+ zones can only be set when you create the scale set.
:type zones: list[str]
"""
@@ -4908,7 +4912,9 @@ class VirtualMachineScaleSetUpdate(UpdateResource):
should be overprovisioned.
:type overprovision: bool
:param single_placement_group: When true this limits the scale set to a
- single placement group, of max size 100 virtual machines.
+ single placement group, of max size 100 virtual machines. NOTE: If
+ singlePlacementGroup is true, it may be modified to false. However, if
+ singlePlacementGroup is false, it may not be modified to true.
:type single_placement_group: bool
:param proximity_placement_group: Specifies information about the
proximity placement group that the virtual machine scale set should be
diff --git a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2018_06_01/models/_models.py b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2018_06_01/models/_models.py
index 99b5dcd0ca2b..9ced68ef4c74 100644
--- a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2018_06_01/models/_models.py
+++ b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2018_06_01/models/_models.py
@@ -1874,7 +1874,8 @@ class ImageReference(SubResource):
about platform images, marketplace images, or virtual machine images. This
element is required when you want to use a platform image, marketplace
image, or virtual machine image, but is not used in other creation
- operations.
+ operations. NOTE: Image reference publisher and offer can only be set when
+ you create the scale set.
:param id: Resource Id
:type id: str
@@ -3404,7 +3405,9 @@ def __init__(self, **kwargs):
class Sku(Model):
- """Describes a virtual machine scale set sku.
+ """Describes a virtual machine scale set sku. NOTE: If the new VM SKU is not
+ supported on the hardware the scale set is currently on, you need to
+ deallocate the VMs in the scale set before you modify the SKU name.
:param name: The sku name.
:type name: str
@@ -4933,7 +4936,8 @@ class VirtualMachineScaleSet(Resource):
configured.
:type identity:
~azure.mgmt.compute.v2018_06_01.models.VirtualMachineScaleSetIdentity
- :param zones: The virtual machine scale set zones.
+ :param zones: The virtual machine scale set zones. NOTE: Availability
+ zones can only be set when you create the scale set.
:type zones: list[str]
"""
@@ -5893,7 +5897,9 @@ class VirtualMachineScaleSetUpdate(UpdateResource):
should be overprovisioned.
:type overprovision: bool
:param single_placement_group: When true this limits the scale set to a
- single placement group, of max size 100 virtual machines.
+ single placement group, of max size 100 virtual machines. NOTE: If
+ singlePlacementGroup is true, it may be modified to false. However, if
+ singlePlacementGroup is false, it may not be modified to true.
:type single_placement_group: bool
:param proximity_placement_group: Specifies information about the
proximity placement group that the virtual machine scale set should be
diff --git a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2018_06_01/models/_models_py3.py b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2018_06_01/models/_models_py3.py
index 40b4cd17e01a..6f4a4f195890 100644
--- a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2018_06_01/models/_models_py3.py
+++ b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2018_06_01/models/_models_py3.py
@@ -1874,7 +1874,8 @@ class ImageReference(SubResource):
about platform images, marketplace images, or virtual machine images. This
element is required when you want to use a platform image, marketplace
image, or virtual machine image, but is not used in other creation
- operations.
+ operations. NOTE: Image reference publisher and offer can only be set when
+ you create the scale set.
:param id: Resource Id
:type id: str
@@ -3404,7 +3405,9 @@ def __init__(self, *, value=None, **kwargs) -> None:
class Sku(Model):
- """Describes a virtual machine scale set sku.
+ """Describes a virtual machine scale set sku. NOTE: If the new VM SKU is not
+ supported on the hardware the scale set is currently on, you need to
+ deallocate the VMs in the scale set before you modify the SKU name.
:param name: The sku name.
:type name: str
@@ -4933,7 +4936,8 @@ class VirtualMachineScaleSet(Resource):
configured.
:type identity:
~azure.mgmt.compute.v2018_06_01.models.VirtualMachineScaleSetIdentity
- :param zones: The virtual machine scale set zones.
+ :param zones: The virtual machine scale set zones. NOTE: Availability
+ zones can only be set when you create the scale set.
:type zones: list[str]
"""
@@ -5893,7 +5897,9 @@ class VirtualMachineScaleSetUpdate(UpdateResource):
should be overprovisioned.
:type overprovision: bool
:param single_placement_group: When true this limits the scale set to a
- single placement group, of max size 100 virtual machines.
+ single placement group, of max size 100 virtual machines. NOTE: If
+ singlePlacementGroup is true, it may be modified to false. However, if
+ singlePlacementGroup is false, it may not be modified to true.
:type single_placement_group: bool
:param proximity_placement_group: Specifies information about the
proximity placement group that the virtual machine scale set should be
diff --git a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2018_10_01/models/_models.py b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2018_10_01/models/_models.py
index 9f833a1e2aa9..ea0621ae3841 100644
--- a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2018_10_01/models/_models.py
+++ b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2018_10_01/models/_models.py
@@ -208,7 +208,7 @@ class AutomaticRepairsPolicy(Model):
state change has completed. This helps avoid premature or accidental
repairs. The time duration should be specified in ISO 8601 format. The
minimum allowed grace period is 30 minutes (PT30M), which is also the
- default value.
+ default value. The maximum allowed grace period is 90 minutes (PT90M).
:type grace_period: str
"""
@@ -1006,7 +1006,8 @@ class ImageReference(SubResource):
about platform images, marketplace images, or virtual machine images. This
element is required when you want to use a platform image, marketplace
image, or virtual machine image, but is not used in other creation
- operations.
+ operations. NOTE: Image reference publisher and offer can only be set when
+ you create the scale set.
:param id: Resource Id
:type id: str
@@ -2343,7 +2344,9 @@ def __init__(self, **kwargs):
class Sku(Model):
- """Describes a virtual machine scale set sku.
+ """Describes a virtual machine scale set sku. NOTE: If the new VM SKU is not
+ supported on the hardware the scale set is currently on, you need to
+ deallocate the VMs in the scale set before you modify the SKU name.
:param name: The sku name.
:type name: str
@@ -3684,7 +3687,8 @@ class VirtualMachineScaleSet(Resource):
configured.
:type identity:
~azure.mgmt.compute.v2018_10_01.models.VirtualMachineScaleSetIdentity
- :param zones: The virtual machine scale set zones.
+ :param zones: The virtual machine scale set zones. NOTE: Availability
+ zones can only be set when you create the scale set.
:type zones: list[str]
"""
@@ -4656,7 +4660,9 @@ class VirtualMachineScaleSetUpdate(UpdateResource):
not run on the extra overprovisioned VMs.
:type do_not_run_extensions_on_overprovisioned_vms: bool
:param single_placement_group: When true this limits the scale set to a
- single placement group, of max size 100 virtual machines.
+ single placement group, of max size 100 virtual machines. NOTE: If
+ singlePlacementGroup is true, it may be modified to false. However, if
+ singlePlacementGroup is false, it may not be modified to true.
:type single_placement_group: bool
:param proximity_placement_group: Specifies information about the
proximity placement group that the virtual machine scale set should be
diff --git a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2018_10_01/models/_models_py3.py b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2018_10_01/models/_models_py3.py
index 086f534f9fe1..b22fd99e8d7b 100644
--- a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2018_10_01/models/_models_py3.py
+++ b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2018_10_01/models/_models_py3.py
@@ -208,7 +208,7 @@ class AutomaticRepairsPolicy(Model):
state change has completed. This helps avoid premature or accidental
repairs. The time duration should be specified in ISO 8601 format. The
minimum allowed grace period is 30 minutes (PT30M), which is also the
- default value.
+ default value. The maximum allowed grace period is 90 minutes (PT90M).
:type grace_period: str
"""
@@ -1006,7 +1006,8 @@ class ImageReference(SubResource):
about platform images, marketplace images, or virtual machine images. This
element is required when you want to use a platform image, marketplace
image, or virtual machine image, but is not used in other creation
- operations.
+ operations. NOTE: Image reference publisher and offer can only be set when
+ you create the scale set.
:param id: Resource Id
:type id: str
@@ -2343,7 +2344,9 @@ def __init__(self, *, value=None, **kwargs) -> None:
class Sku(Model):
- """Describes a virtual machine scale set sku.
+ """Describes a virtual machine scale set sku. NOTE: If the new VM SKU is not
+ supported on the hardware the scale set is currently on, you need to
+ deallocate the VMs in the scale set before you modify the SKU name.
:param name: The sku name.
:type name: str
@@ -3684,7 +3687,8 @@ class VirtualMachineScaleSet(Resource):
configured.
:type identity:
~azure.mgmt.compute.v2018_10_01.models.VirtualMachineScaleSetIdentity
- :param zones: The virtual machine scale set zones.
+ :param zones: The virtual machine scale set zones. NOTE: Availability
+ zones can only be set when you create the scale set.
:type zones: list[str]
"""
@@ -4656,7 +4660,9 @@ class VirtualMachineScaleSetUpdate(UpdateResource):
not run on the extra overprovisioned VMs.
:type do_not_run_extensions_on_overprovisioned_vms: bool
:param single_placement_group: When true this limits the scale set to a
- single placement group, of max size 100 virtual machines.
+ single placement group, of max size 100 virtual machines. NOTE: If
+ singlePlacementGroup is true, it may be modified to false. However, if
+ singlePlacementGroup is false, it may not be modified to true.
:type single_placement_group: bool
:param proximity_placement_group: Specifies information about the
proximity placement group that the virtual machine scale set should be
diff --git a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_03_01/models/_models.py b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_03_01/models/_models.py
index f848c5305a81..99b847975a07 100644
--- a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_03_01/models/_models.py
+++ b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_03_01/models/_models.py
@@ -231,7 +231,7 @@ class AutomaticRepairsPolicy(Model):
state change has completed. This helps avoid premature or accidental
repairs. The time duration should be specified in ISO 8601 format. The
minimum allowed grace period is 30 minutes (PT30M), which is also the
- default value.
+ default value. The maximum allowed grace period is 90 minutes (PT90M).
:type grace_period: str
"""
@@ -2628,7 +2628,8 @@ class ImageReference(SubResource):
about platform images, marketplace images, or virtual machine images. This
element is required when you want to use a platform image, marketplace
image, or virtual machine image, but is not used in other creation
- operations.
+ operations. NOTE: Image reference publisher and offer can only be set when
+ you create the scale set.
:param id: Resource Id
:type id: str
@@ -4220,7 +4221,9 @@ def __init__(self, **kwargs):
class Sku(Model):
- """Describes a virtual machine scale set sku.
+ """Describes a virtual machine scale set sku. NOTE: If the new VM SKU is not
+ supported on the hardware the scale set is currently on, you need to
+ deallocate the VMs in the scale set before you modify the SKU name.
:param name: The sku name.
:type name: str
@@ -5904,7 +5907,8 @@ class VirtualMachineScaleSet(Resource):
configured.
:type identity:
~azure.mgmt.compute.v2019_03_01.models.VirtualMachineScaleSetIdentity
- :param zones: The virtual machine scale set zones.
+ :param zones: The virtual machine scale set zones. NOTE: Availability
+ zones can only be set when you create the scale set.
:type zones: list[str]
"""
@@ -6880,7 +6884,9 @@ class VirtualMachineScaleSetUpdate(UpdateResource):
not run on the extra overprovisioned VMs.
:type do_not_run_extensions_on_overprovisioned_vms: bool
:param single_placement_group: When true this limits the scale set to a
- single placement group, of max size 100 virtual machines.
+ single placement group, of max size 100 virtual machines. NOTE: If
+ singlePlacementGroup is true, it may be modified to false. However, if
+ singlePlacementGroup is false, it may not be modified to true.
:type single_placement_group: bool
:param additional_capabilities: Specifies additional capabilities enabled
or disabled on the Virtual Machines in the Virtual Machine Scale Set. For
diff --git a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_03_01/models/_models_py3.py b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_03_01/models/_models_py3.py
index 5c6854732a4d..736ce87ea1fd 100644
--- a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_03_01/models/_models_py3.py
+++ b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_03_01/models/_models_py3.py
@@ -231,7 +231,7 @@ class AutomaticRepairsPolicy(Model):
state change has completed. This helps avoid premature or accidental
repairs. The time duration should be specified in ISO 8601 format. The
minimum allowed grace period is 30 minutes (PT30M), which is also the
- default value.
+ default value. The maximum allowed grace period is 90 minutes (PT90M).
:type grace_period: str
"""
@@ -2628,7 +2628,8 @@ class ImageReference(SubResource):
about platform images, marketplace images, or virtual machine images. This
element is required when you want to use a platform image, marketplace
image, or virtual machine image, but is not used in other creation
- operations.
+ operations. NOTE: Image reference publisher and offer can only be set when
+ you create the scale set.
:param id: Resource Id
:type id: str
@@ -4220,7 +4221,9 @@ def __init__(self, *, terminate_notification_profile=None, **kwargs) -> None:
class Sku(Model):
- """Describes a virtual machine scale set sku.
+ """Describes a virtual machine scale set sku. NOTE: If the new VM SKU is not
+ supported on the hardware the scale set is currently on, you need to
+ deallocate the VMs in the scale set before you modify the SKU name.
:param name: The sku name.
:type name: str
@@ -5904,7 +5907,8 @@ class VirtualMachineScaleSet(Resource):
configured.
:type identity:
~azure.mgmt.compute.v2019_03_01.models.VirtualMachineScaleSetIdentity
- :param zones: The virtual machine scale set zones.
+ :param zones: The virtual machine scale set zones. NOTE: Availability
+ zones can only be set when you create the scale set.
:type zones: list[str]
"""
@@ -6880,7 +6884,9 @@ class VirtualMachineScaleSetUpdate(UpdateResource):
not run on the extra overprovisioned VMs.
:type do_not_run_extensions_on_overprovisioned_vms: bool
:param single_placement_group: When true this limits the scale set to a
- single placement group, of max size 100 virtual machines.
+ single placement group, of max size 100 virtual machines. NOTE: If
+ singlePlacementGroup is true, it may be modified to false. However, if
+ singlePlacementGroup is false, it may not be modified to true.
:type single_placement_group: bool
:param additional_capabilities: Specifies additional capabilities enabled
or disabled on the Virtual Machines in the Virtual Machine Scale Set. For
diff --git a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_04_01/operations/_resource_skus_operations.py b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_04_01/operations/_resource_skus_operations.py
index 8ba3992094fc..9f39e7f117cd 100644
--- a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_04_01/operations/_resource_skus_operations.py
+++ b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_04_01/operations/_resource_skus_operations.py
@@ -44,7 +44,8 @@ def list(
"""Gets the list of Microsoft.Compute SKUs available for your
Subscription.
- :param filter: The filter to apply on the operation.
+ :param filter: The filter to apply on the operation. Only **location**
+ filter is supported currently.
:type filter: str
:param dict custom_headers: headers that will be added to the request
:param bool raw: returns the direct response alongside the
diff --git a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_07_01/models/_models.py b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_07_01/models/_models.py
index 5ac6a42a34c8..dcfed2b5efd9 100644
--- a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_07_01/models/_models.py
+++ b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_07_01/models/_models.py
@@ -231,7 +231,7 @@ class AutomaticRepairsPolicy(Model):
state change has completed. This helps avoid premature or accidental
repairs. The time duration should be specified in ISO 8601 format. The
minimum allowed grace period is 30 minutes (PT30M), which is also the
- default value.
+ default value. The maximum allowed grace period is 90 minutes (PT90M).
:type grace_period: str
"""
@@ -2249,17 +2249,11 @@ def __init__(self, **kwargs):
class GalleryArtifactVersionSource(Model):
"""The gallery artifact version source.
- All required parameters must be populated in order to send to Azure.
-
- :param id: Required. The id of the gallery artifact version source. Can
- specify a disk uri, snapshot uri, or user image.
+ :param id: The id of the gallery artifact version source. Can specify a
+ disk uri, snapshot uri, or user image.
:type id: str
"""
- _validation = {
- 'id': {'required': True},
- }
-
_attribute_map = {
'id': {'key': 'id', 'type': 'str'},
}
@@ -3315,7 +3309,8 @@ class ImageReference(SubResource):
about platform images, marketplace images, or virtual machine images. This
element is required when you want to use a platform image, marketplace
image, or virtual machine image, but is not used in other creation
- operations.
+ operations. NOTE: Image reference publisher and offer can only be set when
+ you create the scale set.
Variables are only populated by the server, and will be ignored when
sending a request.
@@ -4054,7 +4049,7 @@ class OSProfile(Model):
customData property**
This property cannot be updated after the
VM is created.
customData is passed to the VM to be saved as a
file, for more information see [Custom Data on Azure
- VMs](https://azure.microsoft.com/en-us/blog/custom-data-and-cloud-init-on-windows-azure/)
+ VMs](https://docs.microsoft.com/azure/virtual-machines/custom-data)
For using cloud-init for your Linux VM, see [Using cloud-init to
customize a Linux VM during
creation](https://docs.microsoft.com/azure/virtual-machines/virtual-machines-linux-using-cloud-init?toc=%2fazure%2fvirtual-machines%2flinux%2ftoc.json)
@@ -4971,7 +4966,9 @@ def __init__(self, **kwargs):
class Sku(Model):
- """Describes a virtual machine scale set sku.
+ """Describes a virtual machine scale set sku. NOTE: If the new VM SKU is not
+ supported on the hardware the scale set is currently on, you need to
+ deallocate the VMs in the scale set before you modify the SKU name.
:param name: The sku name.
:type name: str
@@ -6709,7 +6706,8 @@ class VirtualMachineScaleSet(Resource):
configured.
:type identity:
~azure.mgmt.compute.v2019_07_01.models.VirtualMachineScaleSetIdentity
- :param zones: The virtual machine scale set zones.
+ :param zones: The virtual machine scale set zones. NOTE: Availability
+ zones can only be set when you create the scale set.
:type zones: list[str]
"""
@@ -7805,7 +7803,9 @@ class VirtualMachineScaleSetUpdate(UpdateResource):
not run on the extra overprovisioned VMs.
:type do_not_run_extensions_on_overprovisioned_vms: bool
:param single_placement_group: When true this limits the scale set to a
- single placement group, of max size 100 virtual machines.
+ single placement group, of max size 100 virtual machines.NOTE: If
+ singlePlacementGroup is true, it may be modified to false. However, if
+ singlePlacementGroup is false, it may not be modified to true.
:type single_placement_group: bool
:param additional_capabilities: Specifies additional capabilities enabled
or disabled on the Virtual Machines in the Virtual Machine Scale Set. For
diff --git a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_07_01/models/_models_py3.py b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_07_01/models/_models_py3.py
index f85b895c57a3..4fddfaa6cf45 100644
--- a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_07_01/models/_models_py3.py
+++ b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_07_01/models/_models_py3.py
@@ -231,7 +231,7 @@ class AutomaticRepairsPolicy(Model):
state change has completed. This helps avoid premature or accidental
repairs. The time duration should be specified in ISO 8601 format. The
minimum allowed grace period is 30 minutes (PT30M), which is also the
- default value.
+ default value. The maximum allowed grace period is 90 minutes (PT90M).
:type grace_period: str
"""
@@ -2249,22 +2249,16 @@ def __init__(self, *, managed_image, **kwargs) -> None:
class GalleryArtifactVersionSource(Model):
"""The gallery artifact version source.
- All required parameters must be populated in order to send to Azure.
-
- :param id: Required. The id of the gallery artifact version source. Can
- specify a disk uri, snapshot uri, or user image.
+ :param id: The id of the gallery artifact version source. Can specify a
+ disk uri, snapshot uri, or user image.
:type id: str
"""
- _validation = {
- 'id': {'required': True},
- }
-
_attribute_map = {
'id': {'key': 'id', 'type': 'str'},
}
- def __init__(self, *, id: str, **kwargs) -> None:
+ def __init__(self, *, id: str=None, **kwargs) -> None:
super(GalleryArtifactVersionSource, self).__init__(**kwargs)
self.id = id
@@ -3315,7 +3309,8 @@ class ImageReference(SubResource):
about platform images, marketplace images, or virtual machine images. This
element is required when you want to use a platform image, marketplace
image, or virtual machine image, but is not used in other creation
- operations.
+ operations. NOTE: Image reference publisher and offer can only be set when
+ you create the scale set.
Variables are only populated by the server, and will be ignored when
sending a request.
@@ -4054,7 +4049,7 @@ class OSProfile(Model):
customData property**
This property cannot be updated after the
VM is created.
customData is passed to the VM to be saved as a
file, for more information see [Custom Data on Azure
- VMs](https://azure.microsoft.com/en-us/blog/custom-data-and-cloud-init-on-windows-azure/)
+ VMs](https://docs.microsoft.com/azure/virtual-machines/custom-data)
For using cloud-init for your Linux VM, see [Using cloud-init to
customize a Linux VM during
creation](https://docs.microsoft.com/azure/virtual-machines/virtual-machines-linux-using-cloud-init?toc=%2fazure%2fvirtual-machines%2flinux%2ftoc.json)
@@ -4971,7 +4966,9 @@ def __init__(self, *, terminate_notification_profile=None, **kwargs) -> None:
class Sku(Model):
- """Describes a virtual machine scale set sku.
+ """Describes a virtual machine scale set sku. NOTE: If the new VM SKU is not
+ supported on the hardware the scale set is currently on, you need to
+ deallocate the VMs in the scale set before you modify the SKU name.
:param name: The sku name.
:type name: str
@@ -6709,7 +6706,8 @@ class VirtualMachineScaleSet(Resource):
configured.
:type identity:
~azure.mgmt.compute.v2019_07_01.models.VirtualMachineScaleSetIdentity
- :param zones: The virtual machine scale set zones.
+ :param zones: The virtual machine scale set zones. NOTE: Availability
+ zones can only be set when you create the scale set.
:type zones: list[str]
"""
@@ -7805,7 +7803,9 @@ class VirtualMachineScaleSetUpdate(UpdateResource):
not run on the extra overprovisioned VMs.
:type do_not_run_extensions_on_overprovisioned_vms: bool
:param single_placement_group: When true this limits the scale set to a
- single placement group, of max size 100 virtual machines.
+ single placement group, of max size 100 virtual machines.NOTE: If
+ singlePlacementGroup is true, it may be modified to false. However, if
+ singlePlacementGroup is false, it may not be modified to true.
:type single_placement_group: bool
:param additional_capabilities: Specifies additional capabilities enabled
or disabled on the Virtual Machines in the Virtual Machine Scale Set. For
diff --git a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_12_01/models/__init__.py b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_12_01/models/__init__.py
index 1ae624b1ac57..c2ad29b3c283 100644
--- a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_12_01/models/__init__.py
+++ b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_12_01/models/__init__.py
@@ -434,6 +434,7 @@
DiskCreateOptionTypes,
StorageAccountTypes,
DiffDiskOptions,
+ DiffDiskPlacement,
PassNames,
ComponentNames,
SettingNames,
@@ -693,6 +694,7 @@
'DiskCreateOptionTypes',
'StorageAccountTypes',
'DiffDiskOptions',
+ 'DiffDiskPlacement',
'PassNames',
'ComponentNames',
'SettingNames',
diff --git a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_12_01/models/_compute_management_client_enums.py b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_12_01/models/_compute_management_client_enums.py
index 085de025e548..c79b21c55929 100644
--- a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_12_01/models/_compute_management_client_enums.py
+++ b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_12_01/models/_compute_management_client_enums.py
@@ -247,6 +247,12 @@ class DiffDiskOptions(str, Enum):
local = "Local"
+class DiffDiskPlacement(str, Enum):
+
+ cache_disk = "CacheDisk"
+ resource_disk = "ResourceDisk"
+
+
class PassNames(str, Enum):
oobe_system = "OobeSystem"
@@ -333,6 +339,7 @@ class IPVersion(str, Enum):
class OrchestrationServiceNames(str, Enum):
automatic_repairs = "AutomaticRepairs"
+
class OrchestrationServiceState(str, Enum):
@@ -417,6 +424,7 @@ class StorageAccountType(str, Enum):
standard_lrs = "Standard_LRS"
standard_zrs = "Standard_ZRS"
+ premium_lrs = "Premium_LRS"
class HostCaching(str, Enum):
diff --git a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_12_01/operations/_virtual_machine_scale_set_vms_operations.py b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_12_01/operations/_virtual_machine_scale_set_vms_operations.py
index 992f86b8be12..5087f2b92d8e 100644
--- a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_12_01/operations/_virtual_machine_scale_set_vms_operations.py
+++ b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_12_01/operations/_virtual_machine_scale_set_vms_operations.py
@@ -1154,6 +1154,91 @@ def get_long_running_output(response):
perform_maintenance.metadata = {'url': '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Compute/virtualMachineScaleSets/{vmScaleSetName}/virtualmachines/{instanceId}/performMaintenance'}
+ def _simulate_eviction_initial(
+ self, resource_group_name, vm_scale_set_name, instance_id, custom_headers=None, raw=False, **operation_config):
+ # Construct URL
+ url = self.simulate_eviction.metadata['url']
+ path_format_arguments = {
+ 'resourceGroupName': self._serialize.url("resource_group_name", resource_group_name, 'str'),
+ 'vmScaleSetName': self._serialize.url("vm_scale_set_name", vm_scale_set_name, 'str'),
+ 'instanceId': self._serialize.url("instance_id", instance_id, 'str'),
+ 'subscriptionId': self._serialize.url("self.config.subscription_id", self.config.subscription_id, 'str')
+ }
+ url = self._client.format_url(url, **path_format_arguments)
+
+ # Construct parameters
+ query_parameters = {}
+ query_parameters['api-version'] = self._serialize.query("self.api_version", self.api_version, 'str')
+
+ # Construct headers
+ header_parameters = {}
+ if self.config.generate_client_request_id:
+ header_parameters['x-ms-client-request-id'] = str(uuid.uuid1())
+ if custom_headers:
+ header_parameters.update(custom_headers)
+ if self.config.accept_language is not None:
+ header_parameters['accept-language'] = self._serialize.header("self.config.accept_language", self.config.accept_language, 'str')
+
+ # Construct and send request
+ request = self._client.post(url, query_parameters, header_parameters)
+ response = self._client.send(request, stream=False, **operation_config)
+
+ if response.status_code not in [204]:
+ exp = CloudError(response)
+ exp.request_id = response.headers.get('x-ms-request-id')
+ raise exp
+
+ if raw:
+ client_raw_response = ClientRawResponse(None, response)
+ return client_raw_response
+
+ def simulate_eviction(
+ self, resource_group_name, vm_scale_set_name, instance_id, custom_headers=None, raw=False, polling=True, **operation_config):
+ """The operation to simulate the eviction of spot virtual machine in a VM
+ scale set. The eviction will occur within 30 minutes of calling the
+ API.
+
+ :param resource_group_name: The name of the resource group.
+ :type resource_group_name: str
+ :param vm_scale_set_name: The name of the VM scale set.
+ :type vm_scale_set_name: str
+ :param instance_id: The instance ID of the virtual machine.
+ :type instance_id: str
+ :param dict custom_headers: headers that will be added to the request
+ :param bool raw: The poller return type is ClientRawResponse, the
+ direct response alongside the deserialized response
+ :param polling: True for ARMPolling, False for no polling, or a
+ polling object for personal polling strategy
+ :return: An instance of LROPoller that returns None or
+ ClientRawResponse if raw==True
+ :rtype: ~msrestazure.azure_operation.AzureOperationPoller[None] or
+ ~msrestazure.azure_operation.AzureOperationPoller[~msrest.pipeline.ClientRawResponse[None]]
+ :raises: :class:`CloudError`
+ """
+ raw_result = self._simulate_eviction_initial(
+ resource_group_name=resource_group_name,
+ vm_scale_set_name=vm_scale_set_name,
+ instance_id=instance_id,
+ custom_headers=custom_headers,
+ raw=True,
+ **operation_config
+ )
+
+ def get_long_running_output(response):
+ if raw:
+ client_raw_response = ClientRawResponse(None, response)
+ return client_raw_response
+
+ lro_delay = operation_config.get(
+ 'long_running_operation_timeout',
+ self.config.long_running_operation_timeout)
+ if polling is True: polling_method = ARMPolling(lro_delay, **operation_config)
+ elif polling is False: polling_method = NoPolling()
+ else: polling_method = polling
+ return LROPoller(self._client, raw_result, get_long_running_output, polling_method)
+ simulate_eviction.metadata = {'url': '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Compute/virtualMachineScaleSets/{vmScaleSetName}/virtualMachines/{instanceId}/simulateEviction'}
+
+
def _run_command_initial(
self, resource_group_name, vm_scale_set_name, instance_id, parameters, custom_headers=None, raw=False, **operation_config):
# Construct URL
diff --git a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_12_01/operations/_virtual_machine_scale_sets_operations.py b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_12_01/operations/_virtual_machine_scale_sets_operations.py
index bd166bc7a8a4..6ba4bdd814a8 100644
--- a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_12_01/operations/_virtual_machine_scale_sets_operations.py
+++ b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_12_01/operations/_virtual_machine_scale_sets_operations.py
@@ -1840,8 +1840,8 @@ def convert_to_single_placement_group(
def _set_orchestration_service_state_initial(
- self, resource_group_name, vm_scale_set_name, action, custom_headers=None, raw=False, **operation_config):
- parameters = models.OrchestrationServiceStateInput(action=action)
+ self, resource_group_name, vm_scale_set_name, service_name, action, custom_headers=None, raw=False, **operation_config):
+ parameters = models.OrchestrationServiceStateInput(service_name=service_name, action=action)
# Construct URL
url = self.set_orchestration_service_state.metadata['url']
@@ -1883,7 +1883,7 @@ def _set_orchestration_service_state_initial(
return client_raw_response
def set_orchestration_service_state(
- self, resource_group_name, vm_scale_set_name, action, custom_headers=None, raw=False, polling=True, **operation_config):
+ self, resource_group_name, vm_scale_set_name, service_name, action, custom_headers=None, raw=False, polling=True, **operation_config):
"""Changes ServiceState property for a given service.
:param resource_group_name: The name of the resource group.
@@ -1891,6 +1891,10 @@ def set_orchestration_service_state(
:param vm_scale_set_name: The name of the virtual machine scale set to
create or update.
:type vm_scale_set_name: str
+ :param service_name: The name of the service. Possible values include:
+ 'AutomaticRepairs'
+ :type service_name: str or
+ ~azure.mgmt.compute.v2019_12_01.models.OrchestrationServiceNames
:param action: The action to be performed. Possible values include:
'Resume', 'Suspend'
:type action: str or
@@ -1909,6 +1913,7 @@ def set_orchestration_service_state(
raw_result = self._set_orchestration_service_state_initial(
resource_group_name=resource_group_name,
vm_scale_set_name=vm_scale_set_name,
+ service_name=service_name,
action=action,
custom_headers=custom_headers,
raw=True,
diff --git a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_12_01/operations/_virtual_machines_operations.py b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_12_01/operations/_virtual_machines_operations.py
index 0e9624711a6b..7793786ae0ac 100644
--- a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_12_01/operations/_virtual_machines_operations.py
+++ b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_12_01/operations/_virtual_machines_operations.py
@@ -1654,6 +1654,86 @@ def get_long_running_output(response):
perform_maintenance.metadata = {'url': '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Compute/virtualMachines/{vmName}/performMaintenance'}
+ def _simulate_eviction_initial(
+ self, resource_group_name, vm_name, custom_headers=None, raw=False, **operation_config):
+ # Construct URL
+ url = self.simulate_eviction.metadata['url']
+ path_format_arguments = {
+ 'resourceGroupName': self._serialize.url("resource_group_name", resource_group_name, 'str'),
+ 'vmName': self._serialize.url("vm_name", vm_name, 'str'),
+ 'subscriptionId': self._serialize.url("self.config.subscription_id", self.config.subscription_id, 'str')
+ }
+ url = self._client.format_url(url, **path_format_arguments)
+
+ # Construct parameters
+ query_parameters = {}
+ query_parameters['api-version'] = self._serialize.query("self.api_version", self.api_version, 'str')
+
+ # Construct headers
+ header_parameters = {}
+ if self.config.generate_client_request_id:
+ header_parameters['x-ms-client-request-id'] = str(uuid.uuid1())
+ if custom_headers:
+ header_parameters.update(custom_headers)
+ if self.config.accept_language is not None:
+ header_parameters['accept-language'] = self._serialize.header("self.config.accept_language", self.config.accept_language, 'str')
+
+ # Construct and send request
+ request = self._client.post(url, query_parameters, header_parameters)
+ response = self._client.send(request, stream=False, **operation_config)
+
+ if response.status_code not in [204]:
+ exp = CloudError(response)
+ exp.request_id = response.headers.get('x-ms-request-id')
+ raise exp
+
+ if raw:
+ client_raw_response = ClientRawResponse(None, response)
+ return client_raw_response
+
+ def simulate_eviction(
+ self, resource_group_name, vm_name, custom_headers=None, raw=False, polling=True, **operation_config):
+ """The operation to simulate the eviction of spot virtual machine. The
+ eviction will occur within 30 minutes of calling the API.
+
+ :param resource_group_name: The name of the resource group.
+ :type resource_group_name: str
+ :param vm_name: The name of the virtual machine.
+ :type vm_name: str
+ :param dict custom_headers: headers that will be added to the request
+ :param bool raw: The poller return type is ClientRawResponse, the
+ direct response alongside the deserialized response
+ :param polling: True for ARMPolling, False for no polling, or a
+ polling object for personal polling strategy
+ :return: An instance of LROPoller that returns None or
+ ClientRawResponse if raw==True
+ :rtype: ~msrestazure.azure_operation.AzureOperationPoller[None] or
+ ~msrestazure.azure_operation.AzureOperationPoller[~msrest.pipeline.ClientRawResponse[None]]
+ :raises: :class:`CloudError`
+ """
+ raw_result = self._simulate_eviction_initial(
+ resource_group_name=resource_group_name,
+ vm_name=vm_name,
+ custom_headers=custom_headers,
+ raw=True,
+ **operation_config
+ )
+
+ def get_long_running_output(response):
+ if raw:
+ client_raw_response = ClientRawResponse(None, response)
+ return client_raw_response
+
+ lro_delay = operation_config.get(
+ 'long_running_operation_timeout',
+ self.config.long_running_operation_timeout)
+ if polling is True: polling_method = ARMPolling(lro_delay, **operation_config)
+ elif polling is False: polling_method = NoPolling()
+ else: polling_method = polling
+ return LROPoller(self._client, raw_result, get_long_running_output, polling_method)
+ simulate_eviction.metadata = {'url': '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Compute/virtualMachines/{vmName}/simulateEviction'}
+
+
def _run_command_initial(
self, resource_group_name, vm_name, parameters, custom_headers=None, raw=False, **operation_config):
# Construct URL
diff --git a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_12_01/models/_models.py b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_12_01/models/_models.py
index fa9f6d34f8ad..2dba191f3b84 100644
--- a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_12_01/models/_models.py
+++ b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_12_01/models/_models.py
@@ -208,7 +208,7 @@ class AutomaticRepairsPolicy(Model):
state change has completed. This helps avoid premature or accidental
repairs. The time duration should be specified in ISO 8601 format. The
minimum allowed grace period is 30 minutes (PT30M), which is also the
- default value.
+ default value. The maximum allowed grace period is 90 minutes (PT90M).
:type grace_period: str
"""
@@ -1138,15 +1138,29 @@ class DiffDiskSettings(Model):
disk. Possible values include: 'Local'
:type option: str or
~azure.mgmt.compute.v2019_12_01.models.DiffDiskOptions
+ :param placement: Specifies the ephemeral disk placement for operating
+ system disk.
Possible values are:
**CacheDisk**
+ **ResourceDisk**
Default: **CacheDisk** if one is configured for
+ the VM size otherwise **ResourceDisk** is used.
Refer to VM size
+ documentation for Windows VM at
+ https://docs.microsoft.com/en-us/azure/virtual-machines/windows/sizes and
+ Linux VM at
+ https://docs.microsoft.com/en-us/azure/virtual-machines/linux/sizes to
+ check which VM sizes exposes a cache disk. Possible values include:
+ 'CacheDisk', 'ResourceDisk'
+ :type placement: str or
+ ~azure.mgmt.compute.v2019_12_01.models.DiffDiskPlacement
"""
_attribute_map = {
'option': {'key': 'option', 'type': 'str'},
+ 'placement': {'key': 'placement', 'type': 'str'},
}
def __init__(self, **kwargs):
super(DiffDiskSettings, self).__init__(**kwargs)
self.option = kwargs.get('option', None)
+ self.placement = kwargs.get('placement', None)
class Disallowed(Model):
@@ -1601,7 +1615,7 @@ class GalleryArtifactPublishingProfileBase(Model):
:type end_of_life_date: datetime
:param storage_account_type: Specifies the storage account type to be used
to store the image. This property is not updatable. Possible values
- include: 'Standard_LRS', 'Standard_ZRS'
+ include: 'Standard_LRS', 'Standard_ZRS', 'Premium_LRS'
:type storage_account_type: str or
~azure.mgmt.compute.v2019_12_01.models.StorageAccountType
"""
@@ -1657,7 +1671,7 @@ class GalleryApplicationVersionPublishingProfile(GalleryArtifactPublishingProfil
:type end_of_life_date: datetime
:param storage_account_type: Specifies the storage account type to be used
to store the image. This property is not updatable. Possible values
- include: 'Standard_LRS', 'Standard_ZRS'
+ include: 'Standard_LRS', 'Standard_ZRS', 'Premium_LRS'
:type storage_account_type: str or
~azure.mgmt.compute.v2019_12_01.models.StorageAccountType
:param source: Required.
@@ -1777,17 +1791,11 @@ def __init__(self, **kwargs):
class GalleryArtifactVersionSource(Model):
"""The gallery artifact version source.
- All required parameters must be populated in order to send to Azure.
-
- :param id: Required. The id of the gallery artifact version source. Can
- specify a disk uri, snapshot uri, or user image.
+ :param id: The id of the gallery artifact version source. Can specify a
+ disk uri, snapshot uri, or user image.
:type id: str
"""
- _validation = {
- 'id': {'required': True},
- }
-
_attribute_map = {
'id': {'key': 'id', 'type': 'str'},
}
@@ -2251,7 +2259,7 @@ class GalleryImageVersionPublishingProfile(GalleryArtifactPublishingProfileBase)
:type end_of_life_date: datetime
:param storage_account_type: Specifies the storage account type to be used
to store the image. This property is not updatable. Possible values
- include: 'Standard_LRS', 'Standard_ZRS'
+ include: 'Standard_LRS', 'Standard_ZRS', 'Premium_LRS'
:type storage_account_type: str or
~azure.mgmt.compute.v2019_12_01.models.StorageAccountType
"""
@@ -2786,7 +2794,8 @@ class ImageReference(SubResource):
about platform images, marketplace images, or virtual machine images. This
element is required when you want to use a platform image, marketplace
image, or virtual machine image, but is not used in other creation
- operations.
+ operations. NOTE: Image reference publisher and offer can only be set when
+ you create the scale set.
Variables are only populated by the server, and will be ignored when
sending a request.
@@ -3294,14 +3303,12 @@ def __init__(self, **kwargs):
class OrchestrationServiceStateInput(Model):
"""The input for OrchestrationServiceState.
- Variables are only populated by the server, and will be ignored when
- sending a request.
-
All required parameters must be populated in order to send to Azure.
- :ivar service_name: Required. The name of the service. Default value:
- "AutomaticRepairs" .
- :vartype service_name: str
+ :param service_name: Required. The name of the service. Possible values
+ include: 'AutomaticRepairs'
+ :type service_name: str or
+ ~azure.mgmt.compute.v2019_12_01.models.OrchestrationServiceNames
:param action: Required. The action to be performed. Possible values
include: 'Resume', 'Suspend'
:type action: str or
@@ -3309,7 +3316,7 @@ class OrchestrationServiceStateInput(Model):
"""
_validation = {
- 'service_name': {'required': True, 'constant': True},
+ 'service_name': {'required': True},
'action': {'required': True},
}
@@ -3318,10 +3325,9 @@ class OrchestrationServiceStateInput(Model):
'action': {'key': 'action', 'type': 'str'},
}
- service_name = "AutomaticRepairs"
-
def __init__(self, **kwargs):
super(OrchestrationServiceStateInput, self).__init__(**kwargs)
+ self.service_name = kwargs.get('service_name', None)
self.action = kwargs.get('action', None)
@@ -3386,8 +3392,8 @@ class OSDisk(Model):
:type image: ~azure.mgmt.compute.v2019_12_01.models.VirtualHardDisk
:param caching: Specifies the caching requirements.
Possible
values are:
**None**
**ReadOnly**
**ReadWrite**
-
Default: **None for Standard storage. ReadOnly for Premium
- storage**. Possible values include: 'None', 'ReadOnly', 'ReadWrite'
+
Default: **None** for Standard storage. **ReadOnly** for Premium
+ storage. Possible values include: 'None', 'ReadOnly', 'ReadWrite'
:type caching: str or ~azure.mgmt.compute.v2019_12_01.models.CachingTypes
:param write_accelerator_enabled: Specifies whether writeAccelerator
should be enabled or disabled on the disk.
@@ -4437,7 +4443,9 @@ def __init__(self, **kwargs):
class Sku(Model):
- """Describes a virtual machine scale set sku.
+ """Describes a virtual machine scale set sku. NOTE: If the new VM SKU is not
+ supported on the hardware the scale set is currently on, you need to
+ deallocate the VMs in the scale set before you modify the SKU name.
:param name: The sku name.
:type name: str
@@ -4707,7 +4715,7 @@ class TargetRegion(Model):
:type regional_replica_count: int
:param storage_account_type: Specifies the storage account type to be used
to store the image. This property is not updatable. Possible values
- include: 'Standard_LRS', 'Standard_ZRS'
+ include: 'Standard_LRS', 'Standard_ZRS', 'Premium_LRS'
:type storage_account_type: str or
~azure.mgmt.compute.v2019_12_01.models.StorageAccountType
:param encryption:
@@ -6037,7 +6045,9 @@ class VirtualMachineScaleSet(Resource):
Machine Scale Set.
:vartype unique_id: str
:param single_placement_group: When true this limits the scale set to a
- single placement group, of max size 100 virtual machines.
+ single placement group, of max size 100 virtual machines. NOTE: If
+ singlePlacementGroup is true, it may be modified to false. However, if
+ singlePlacementGroup is false, it may not be modified to true.
:type single_placement_group: bool
:param zone_balance: Whether to force strictly even Virtual Machine
distribution cross x-zones in case there is zone outage.
@@ -6065,7 +6075,8 @@ class VirtualMachineScaleSet(Resource):
configured.
:type identity:
~azure.mgmt.compute.v2019_12_01.models.VirtualMachineScaleSetIdentity
- :param zones: The virtual machine scale set zones.
+ :param zones: The virtual machine scale set zones. NOTE: Availability
+ zones can only be set when you create the scale set
:type zones: list[str]
"""
@@ -7158,7 +7169,9 @@ class VirtualMachineScaleSetUpdate(UpdateResource):
not run on the extra overprovisioned VMs.
:type do_not_run_extensions_on_overprovisioned_vms: bool
:param single_placement_group: When true this limits the scale set to a
- single placement group, of max size 100 virtual machines.
+ single placement group, of max size 100 virtual machines. NOTE: If
+ singlePlacementGroup is true, it may be modified to false. However, if
+ singlePlacementGroup is false, it may not be modified to true.
:type single_placement_group: bool
:param additional_capabilities: Specifies additional capabilities enabled
or disabled on the Virtual Machines in the Virtual Machine Scale Set. For
@@ -7216,6 +7229,8 @@ def __init__(self, **kwargs):
class VirtualMachineScaleSetUpdateIPConfiguration(SubResource):
"""Describes a virtual machine scale set network profile's IP configuration.
+ NOTE: The subnet of a scale set may be modified as long as the original
+ subnet and the new subnet are in the same virtual network.
:param id: Resource Id
:type id: str
diff --git a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_12_01/models/_models_py3.py b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_12_01/models/_models_py3.py
index 4450606e7a87..cb85b0dba40a 100644
--- a/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_12_01/models/_models_py3.py
+++ b/sdk/compute/azure-mgmt-compute/azure/mgmt/compute/v2019_12_01/models/_models_py3.py
@@ -208,7 +208,7 @@ class AutomaticRepairsPolicy(Model):
state change has completed. This helps avoid premature or accidental
repairs. The time duration should be specified in ISO 8601 format. The
minimum allowed grace period is 30 minutes (PT30M), which is also the
- default value.
+ default value. The maximum allowed grace period is 90 minutes (PT90M).
:type grace_period: str
"""
@@ -1138,15 +1138,29 @@ class DiffDiskSettings(Model):
disk. Possible values include: 'Local'
:type option: str or
~azure.mgmt.compute.v2019_12_01.models.DiffDiskOptions
+ :param placement: Specifies the ephemeral disk placement for operating
+ system disk.
Possible values are:
**CacheDisk**
+ **ResourceDisk**
Default: **CacheDisk** if one is configured for
+ the VM size otherwise **ResourceDisk** is used.
Refer to VM size
+ documentation for Windows VM at
+ https://docs.microsoft.com/en-us/azure/virtual-machines/windows/sizes and
+ Linux VM at
+ https://docs.microsoft.com/en-us/azure/virtual-machines/linux/sizes to
+ check which VM sizes exposes a cache disk. Possible values include:
+ 'CacheDisk', 'ResourceDisk'
+ :type placement: str or
+ ~azure.mgmt.compute.v2019_12_01.models.DiffDiskPlacement
"""
_attribute_map = {
'option': {'key': 'option', 'type': 'str'},
+ 'placement': {'key': 'placement', 'type': 'str'},
}
- def __init__(self, *, option=None, **kwargs) -> None:
+ def __init__(self, *, option=None, placement=None, **kwargs) -> None:
super(DiffDiskSettings, self).__init__(**kwargs)
self.option = option
+ self.placement = placement
class Disallowed(Model):
@@ -1601,7 +1615,7 @@ class GalleryArtifactPublishingProfileBase(Model):
:type end_of_life_date: datetime
:param storage_account_type: Specifies the storage account type to be used
to store the image. This property is not updatable. Possible values
- include: 'Standard_LRS', 'Standard_ZRS'
+ include: 'Standard_LRS', 'Standard_ZRS', 'Premium_LRS'
:type storage_account_type: str or
~azure.mgmt.compute.v2019_12_01.models.StorageAccountType
"""
@@ -1657,7 +1671,7 @@ class GalleryApplicationVersionPublishingProfile(GalleryArtifactPublishingProfil
:type end_of_life_date: datetime
:param storage_account_type: Specifies the storage account type to be used
to store the image. This property is not updatable. Possible values
- include: 'Standard_LRS', 'Standard_ZRS'
+ include: 'Standard_LRS', 'Standard_ZRS', 'Premium_LRS'
:type storage_account_type: str or
~azure.mgmt.compute.v2019_12_01.models.StorageAccountType
:param source: Required.
@@ -1777,22 +1791,16 @@ def __init__(self, *, managed_image, **kwargs) -> None:
class GalleryArtifactVersionSource(Model):
"""The gallery artifact version source.
- All required parameters must be populated in order to send to Azure.
-
- :param id: Required. The id of the gallery artifact version source. Can
- specify a disk uri, snapshot uri, or user image.
+ :param id: The id of the gallery artifact version source. Can specify a
+ disk uri, snapshot uri, or user image.
:type id: str
"""
- _validation = {
- 'id': {'required': True},
- }
-
_attribute_map = {
'id': {'key': 'id', 'type': 'str'},
}
- def __init__(self, *, id: str, **kwargs) -> None:
+ def __init__(self, *, id: str=None, **kwargs) -> None:
super(GalleryArtifactVersionSource, self).__init__(**kwargs)
self.id = id
@@ -2251,7 +2259,7 @@ class GalleryImageVersionPublishingProfile(GalleryArtifactPublishingProfileBase)
:type end_of_life_date: datetime
:param storage_account_type: Specifies the storage account type to be used
to store the image. This property is not updatable. Possible values
- include: 'Standard_LRS', 'Standard_ZRS'
+ include: 'Standard_LRS', 'Standard_ZRS', 'Premium_LRS'
:type storage_account_type: str or
~azure.mgmt.compute.v2019_12_01.models.StorageAccountType
"""
@@ -2786,7 +2794,8 @@ class ImageReference(SubResource):
about platform images, marketplace images, or virtual machine images. This
element is required when you want to use a platform image, marketplace
image, or virtual machine image, but is not used in other creation
- operations.
+ operations. NOTE: Image reference publisher and offer can only be set when
+ you create the scale set.
Variables are only populated by the server, and will be ignored when
sending a request.
@@ -3294,14 +3303,12 @@ def __init__(self, *, network_interfaces=None, **kwargs) -> None:
class OrchestrationServiceStateInput(Model):
"""The input for OrchestrationServiceState.
- Variables are only populated by the server, and will be ignored when
- sending a request.
-
All required parameters must be populated in order to send to Azure.
- :ivar service_name: Required. The name of the service. Default value:
- "AutomaticRepairs" .
- :vartype service_name: str
+ :param service_name: Required. The name of the service. Possible values
+ include: 'AutomaticRepairs'
+ :type service_name: str or
+ ~azure.mgmt.compute.v2019_12_01.models.OrchestrationServiceNames
:param action: Required. The action to be performed. Possible values
include: 'Resume', 'Suspend'
:type action: str or
@@ -3309,7 +3316,7 @@ class OrchestrationServiceStateInput(Model):
"""
_validation = {
- 'service_name': {'required': True, 'constant': True},
+ 'service_name': {'required': True},
'action': {'required': True},
}
@@ -3318,10 +3325,9 @@ class OrchestrationServiceStateInput(Model):
'action': {'key': 'action', 'type': 'str'},
}
- service_name = "AutomaticRepairs"
-
- def __init__(self, *, action, **kwargs) -> None:
+ def __init__(self, *, service_name, action, **kwargs) -> None:
super(OrchestrationServiceStateInput, self).__init__(**kwargs)
+ self.service_name = service_name
self.action = action
@@ -3386,8 +3392,8 @@ class OSDisk(Model):
:type image: ~azure.mgmt.compute.v2019_12_01.models.VirtualHardDisk
:param caching: Specifies the caching requirements.
Possible
values are:
**None**
**ReadOnly**
**ReadWrite**
-
Default: **None for Standard storage. ReadOnly for Premium
- storage**. Possible values include: 'None', 'ReadOnly', 'ReadWrite'
+
Default: **None** for Standard storage. **ReadOnly** for Premium
+ storage. Possible values include: 'None', 'ReadOnly', 'ReadWrite'
:type caching: str or ~azure.mgmt.compute.v2019_12_01.models.CachingTypes
:param write_accelerator_enabled: Specifies whether writeAccelerator
should be enabled or disabled on the disk.
@@ -4437,7 +4443,9 @@ def __init__(self, *, terminate_notification_profile=None, **kwargs) -> None:
class Sku(Model):
- """Describes a virtual machine scale set sku.
+ """Describes a virtual machine scale set sku. NOTE: If the new VM SKU is not
+ supported on the hardware the scale set is currently on, you need to
+ deallocate the VMs in the scale set before you modify the SKU name.
:param name: The sku name.
:type name: str
@@ -4707,7 +4715,7 @@ class TargetRegion(Model):
:type regional_replica_count: int
:param storage_account_type: Specifies the storage account type to be used
to store the image. This property is not updatable. Possible values
- include: 'Standard_LRS', 'Standard_ZRS'
+ include: 'Standard_LRS', 'Standard_ZRS', 'Premium_LRS'
:type storage_account_type: str or
~azure.mgmt.compute.v2019_12_01.models.StorageAccountType
:param encryption:
@@ -6037,7 +6045,9 @@ class VirtualMachineScaleSet(Resource):
Machine Scale Set.
:vartype unique_id: str
:param single_placement_group: When true this limits the scale set to a
- single placement group, of max size 100 virtual machines.
+ single placement group, of max size 100 virtual machines. NOTE: If
+ singlePlacementGroup is true, it may be modified to false. However, if
+ singlePlacementGroup is false, it may not be modified to true.
:type single_placement_group: bool
:param zone_balance: Whether to force strictly even Virtual Machine
distribution cross x-zones in case there is zone outage.
@@ -6065,7 +6075,8 @@ class VirtualMachineScaleSet(Resource):
configured.
:type identity:
~azure.mgmt.compute.v2019_12_01.models.VirtualMachineScaleSetIdentity
- :param zones: The virtual machine scale set zones.
+ :param zones: The virtual machine scale set zones. NOTE: Availability
+ zones can only be set when you create the scale set
:type zones: list[str]
"""
@@ -7158,7 +7169,9 @@ class VirtualMachineScaleSetUpdate(UpdateResource):
not run on the extra overprovisioned VMs.
:type do_not_run_extensions_on_overprovisioned_vms: bool
:param single_placement_group: When true this limits the scale set to a
- single placement group, of max size 100 virtual machines.
+ single placement group, of max size 100 virtual machines. NOTE: If
+ singlePlacementGroup is true, it may be modified to false. However, if
+ singlePlacementGroup is false, it may not be modified to true.
:type single_placement_group: bool
:param additional_capabilities: Specifies additional capabilities enabled
or disabled on the Virtual Machines in the Virtual Machine Scale Set. For
@@ -7216,6 +7229,8 @@ def __init__(self, *, tags=None, sku=None, plan=None, upgrade_policy=None, autom
class VirtualMachineScaleSetUpdateIPConfiguration(SubResource):
"""Describes a virtual machine scale set network profile's IP configuration.
+ NOTE: The subnet of a scale set may be modified as long as the original
+ subnet and the new subnet are in the same virtual network.
:param id: Resource Id
:type id: str